import requests, json
from urllib.parse import urlparse
from mistrs import get_paginated, get, post

#def get_sites(org_id, headers):
    #create a dictionary of ids and sites

#def get_inventory(org_id, headers, hwtype):
    #get inventory based on hw type. returns an array

#def upgrade_site():

#def upgrade_ap(org_id, headers, mac, version):

#def ping_hook():
